@@ -10,6 +10,7 @@ import pytest
 import importlib
 import logging
 import subprocess
+import pandas as pd
 
 import glrestore
 import glrestore.s3_utils
@@ -78,18 +79,35 @@ def test_object_glacerized(BTO):
     upload_glacierized_file()
 
     # Test ability to check non-glacierized file
-    assert glrestore.s3_utils.glacier_status(BTO.non_glacerized_file_loc, profile='sonn') == 'no-glacier'
+    assert glrestore.s3_utils.glacier_status(BTO.non_glacerized_file_loc) == 'no-glacier'
 
     # Test ability to check glacierized file
-    assert glrestore.s3_utils.glacier_status(BTO.glacerized_file_loc, profile='sonn') == 'glacier-no-restore'
+    assert glrestore.s3_utils.glacier_status(BTO.glacerized_file_loc) == 'glacier-no-restore'
 
     # Test ability to recognize *restored* glacierized file
-    assert glrestore.s3_utils.glacier_status(BTO.restored_file_loc, profile='sonn') == 'glacier-restored'
+    assert glrestore.s3_utils.glacier_status(BTO.restored_file_loc) == 'glacier-restored'
 
     # Test ability to recognize *restoring* glacierized file
-    cmd = "aws s3api restore-object --profile sonn --bucket sonn-current --key users/mattolm/testing_house/glrestore/N5_271_010G1_scaffold_min1000.fa --restore-request '{\"Days\":1,\"GlacierJobParameters\":{\"Tier\":\"Expedited\"}}'"
+    cmd = "aws s3api restore-object --bucket sonn-current --key users/mattolm/testing_house/glrestore/N5_271_010G1_scaffold_min1000.fa --restore-request '{\"Days\":1,\"GlacierJobParameters\":{\"Tier\":\"Expedited\"}}'"
     subprocess.call(cmd, shell=True)
-    assert glrestore.s3_utils.glacier_status(BTO.glacerized_file_loc, profile='sonn') == 'glacier-restoring'
+    assert glrestore.s3_utils.glacier_status(BTO.glacerized_file_loc) == 'glacier-restoring'
+
+def test_classify_glacier_objects(BTO):
+    """
+    test the "s3_utils.classify_glacier_objects" function
+    """
+    pd.set_option('display.max_colwidth', None)
+    pd.set_option('display.max_columns', None)
+
+    upload_glacierized_file()
+
+    db = glrestore.s3_utils.classify_glacier_objects(
+        [BTO.non_glacerized_file_loc, BTO.glacerized_file_loc, BTO.restored_file_loc])
+
+    assert len(db) == 3
+    assert db['storage_class'].value_counts()['GLACIER'] == 2
+
+    print(db)
 
 """
 INTEGRATED TESTS
